@@ -364,15 +364,15 @@ class TibberHome:
             return ""
         return self.currency + "/" + self.consumption_unit
 
-    def current_price_data(self) -> tuple[float, str, dt.datetime]:
+    def current_price_data(self) -> tuple[float | None, str | None, dt.datetime | None]:
         """Get current price."""
-        price_time = (
-            dt.datetime.now()
-            .replace(minute=0, second=0, microsecond=0)
-            .astimezone(self._tibber_control.time_zone)
-        )
-        key = price_time.isoformat().replace("+", ".000+")
-        return round(self.price_total[key], 3), self.price_level[key], price_time
+        now = dt.datetime.now(self._tibber_control.time_zone)
+        for key, price_total in self.price_total.items():
+            price_time = parse(key).astimezone(self._tibber_control.time_zone)
+            time_diff = (now - price_time).total_seconds() / 60
+            if 0 <= time_diff < 60:
+                return round(price_total, 3), self.price_level[key], price_time
+        return None, None, None
 
     async def rt_subscribe(self, callback: Callable) -> None:
         """Connect to Tibber and subscribe to Tibber real time subscription.
@@ -418,8 +418,7 @@ class TibberHome:
             restarter = asyncio.create_task(_disconnect())
             while True:
                 try:
-                    if not self.rt_subscription_running:
-                        await self._tibber_control.sub_manager.connect_async()
+                    await self._tibber_control.rt_connect()
                     async for data in self._tibber_control.sub_manager.session.subscribe(
                         gql(LIVE_SUBSCRIBE % self.home_id)
                     ):
@@ -462,22 +461,41 @@ class TibberHome:
             DAILY, WEEKLY, MONTHLY or ANNUAL
         :param production: True to get production data instead of consumption
         """
-        cons_or_prod_str = "production" if production else "consumption"
-        query = HISTORIC_DATA.format(
-            self.home_id,
-            cons_or_prod_str,
-            resolution,
-            n_data,
-            "profit" if production else "totalCost cost",
-        )
-
-        if not (data := await self._tibber_control.execute(query)):
-            _LOGGER.error("Could not get the data.")
-            return []
-        data = data["viewer"]["home"][cons_or_prod_str]
-        if data is None:
-            return []
-        return data["nodes"]
+        cursor = ""
+        res = []
+        max_n_data = 7000
+        while n_data > 0:
+            _n_data = min(max_n_data, n_data)
+            cons_or_prod_str = "production" if production else "consumption"
+            query = HISTORIC_DATA.format(
+                self.home_id,
+                cons_or_prod_str,
+                resolution,
+                _n_data,
+                "profit" if production else "totalCost cost",
+                cursor,
+            )
+            if not (data := await self._tibber_control.execute(query)):
+                _LOGGER.error("Could not get the data.")
+                continue
+            data = data["viewer"]["home"][cons_or_prod_str]
+            if data is None:
+                continue
+            res.extend(data["nodes"])
+            n_data -= len(data["nodes"])
+            if (
+                not data["pageInfo"]["hasPreviousPage"]
+                or not data["pageInfo"]["startCursor"]
+            ):
+                if n_data > 0:
+                    max_n_data = max_n_data // 10
+                    if max_n_data < 1:
+                        _LOGGER.warning("Found less data than requested")
+                        break
+                    continue
+                break
+            cursor = data["pageInfo"]["startCursor"]
+        return res
 
     async def get_historic_price_data(
         self,
